import os
import sys

# default hooks directory
HOOKS_DIR = os.path.expanduser("~/pre-pip/hooks")


def scaffold_hooks_dir(HOOKS_DIR=HOOKS_DIR):
    # Create hooks dir if it doesn't exist
    if not os.path.isdir(HOOKS_DIR):
        # create all parent directories
        os.makedirs(HOOKS_DIR)

    # Ensure there is an init file in the hooks dir if one doesn't exist
    if not os.path.isfile(os.path.join(HOOKS_DIR, "__init__.py")):
        with open(os.path.join(HOOKS_DIR, "__init__.py"), "w") as f:
            f.write("")


scaffold_hooks_dir(HOOKS_DIR)


def main(args: str):
    #  import hooks package
    sys.path.append(HOOKS_DIR)

    for file in os.listdir(HOOKS_DIR):
        if file.endswith(".py") and file != "__init__.py":
            #  import hook
            hook = __import__(file.rstrip(".py"))
            #  run hook
            hook.main(args)


if __name__ == "__main__":
    main()



import os
import shutil
from . import HOOKS_DIR


def uninstall():
    # Check which shell is running
    shell = os.environ.get("SHELL", "sh")

    if "zsh" in shell:
        uninstall_from_rc("zsh")
    elif "bash" in shell:
        uninstall_from_rc("bash")
    else:
        print("Failed to uninstall from unsupported shell.")

    # delete hooks dir
    if os.path.isdir(HOOKS_DIR):
        shutil.rmtree(HOOKS_DIR)


def uninstall_from_rc(shell: str):
    # open rc file
    with open(os.path.expanduser(f"~/.{shell}rc"), "r") as f:
        rc = f.read()

        # check for pre-pip in .rc
        if "pre-pip" in rc:
            # if found, remove it
            # delete all lines between the start and end
            rc = rc.replace(
                rc[
                    rc.find("# pre-pip start") : rc.find("# pre-pip end")  # noqa
                    + len("# pre-pip end")  # noqa
                ],
                "",
            )

            #  remove black lines at the end of rc
            rc = rc.rstrip()

            # add a new line at the end of rc
            rc += "\n"

            # write the new .rc
            with open(os.path.expanduser(f"~/.{shell}rc"), "w") as f:
                f.write(rc)


if __name__ == "__main__":
    uninstall()



import os
import sys
import click
from pathlib import Path
from rich import print as rprint
from .uninstall import uninstall as uninstall_pre_pip
from .install import install as install_pre_pip
from . import HOOKS_DIR, scaffold_hooks_dir
from . import __version__


@click.group()
@click.version_option(__version__, message="pre-pip %(version)s")
@click.pass_context
def cli(ctx):
    """Welcome to the pre-pip CLI!"""
    pass


@cli.command()
def install():
    """Add pre-pip to your shell."""
    scaffold_hooks_dir(HOOKS_DIR)
    install_pre_pip()


@cli.command()
@click.option("--no-prompt", "-np", is_flag=True, help="Do not prompt.")
def uninstall(no_prompt):
    """Remove pre-pip from your shell."""
    if not no_prompt:
        value = click.prompt(
            "Are you sure you want to uninstall pre-pip? (y/n)",
            type=bool,
        )
        if not value:
            sys.exit()
    uninstall_pre_pip()
    rprint("[italic green]pre-pip[/italic green] was successfully uninstalled!")


@cli.command()
@click.argument("hook", type=click.Path(exists=True), required=True, nargs=1)
def add(hook):
    """Add a pre-pip hook."""
    # check if hook exists
    if not os.path.isfile(hook):
        rprint(
            f"[bold red]ERROR:[/bold red] Specified hook [italic cyan]{hook}[/italic cyan] does not exist!"
        )
        sys.exit()
    else:
        # if it does, copy it to HOOKS_DIR
        os.system(f"cp {hook} {HOOKS_DIR}")

        hook_no_ext = Path(hook).stem

        # update the init file
        with open(os.path.join(HOOKS_DIR, "__init__.py"), "r") as f:
            import_statement = f"from .{hook_no_ext} import main as {hook_no_ext}"
            # check if the import statement already exists
            if import_statement not in f.read():
                with open(os.path.join(HOOKS_DIR, "__init__.py"), "a") as f:
                    f.write(import_statement)
                    f.write("\n")

        rprint("[italic green]pre-pip[/italic green] hook added successfully!")


@cli.command()
def list():
    """See installed pre-pip hooks."""
    hooks = os.listdir(HOOKS_DIR)
    if len(hooks) == 1:
        # i.e. only __init__.py
        rprint("No hooks found.")
    else:
        for hook in hooks:
            if hook.endswith(".py") and hook != "__init__.py":
                rprint(f"[italic cyan]{hook.replace('.py', '')}[/italic cyan]")


@cli.command()
@click.option("--all", is_flag=True, help="Remove all pre-pip hooks.")
@click.argument("hook", nargs=1, required=False)
def remove(hook, all):
    """Remove a pre-pip hook."""
    if all:
        # remove all hooks
        hooks = os.listdir(HOOKS_DIR)
        for hook in hooks:
            if hook.endswith(".py") and hook != "__init__.py":
                os.remove(os.path.join(HOOKS_DIR, hook))

        # reset __init__.py
        with open(os.path.join(HOOKS_DIR, "__init__.py"), "w") as f:
            f.write("")

        rprint("All hooks removed successfully!")
    else:
        if hook is None:
            rprint(
                "[bold red]ERROR:[/bold red] Please specify a hook or use the --all flag."
            )
            sys.exit()
        else:
            # remove specified hook
            if os.path.isfile(os.path.join(HOOKS_DIR, f"{hook}.py")):
                os.remove(os.path.join(HOOKS_DIR, f"{hook}.py"))

                # remove the import statement from __init__.py
                with open(os.path.join(HOOKS_DIR, "__init__.py"), "r") as f:
                    lines = f.readlines()

                with open(os.path.join(HOOKS_DIR, "__init__.py"), "w") as f:
                    for line in lines:
                        if f"from .{hook} import main as {hook}" not in line:
                            f.write(line)

                rprint(
                    "[italic green]pre-pip[/italic green] hook removed successfully!"
                )


if __name__ == "__main__":
    cli()



import os
import sys
import subprocess
from rich import print as rprint


pre_pip_script = r"""# pre-pip start
preexec () {
    # check if $1 contains pip
    if [[ "$1" = "pip"* ]]; then
        # call python function
        python3 -c "import pre_pip; pre_pip.main('$1')"
    fi
    return 0
}
# pre-pip end
"""


def install():
    # Check which shell is running
    shell = os.environ.get("SHELL", "sh")

    if "zsh" in shell:
        install_rc("zsh")
    elif "bash" in shell:
        install_bash_preexec()
        install_rc("bash")
    else:
        rprint(
            f"[italic green]pre-pip[/italic green] is unfortunately not currently supported for {shell}."
        )
        sys.exit()


def install_rc(shell: str):
    if shell not in ["bash", "zsh"]:
        rprint(
            f"[italic green]pre-pip[/italic green] is unfortunately not currently supported for {shell}."
        )
        sys.exit()

    # check if rc file exists
    if not os.path.isfile(os.path.expanduser(f"~/.{shell}rc")):
        # create it if it doesn't exist
        with open(os.path.expanduser(f"~/.{shell}rc"), "w") as f:
            f.write("")

    # check for pre-pip in .zshrc
    with open(os.path.expanduser(f"~/.{shell}rc"), "r") as f:
        shell_rc = f.read()

    if "pre-pip" not in shell_rc:
        # installing pre-pip
        with open(os.path.expanduser(f"~/.{shell}rc"), "a") as f:
            f.write("\n")
            f.write(pre_pip_script)

        rprint("[italic green]pre-pip[/italic green] was installed! \n")

        # ask to reload shell rc file
        rprint(
            f"Please run `[cyan]source ~/.{shell}rc[/cyan]` to reload your configuration."
        )
    else:
        rprint("[italic green]pre-pip[/italic green] is already installed!")


def install_bash_preexec():
    # check if .bashrc exists
    if not os.path.isfile(os.path.expanduser("~/.bashrc")):
        # create .bashrc if it doesn't exist
        with open(os.path.expanduser("~/.bashrc"), "w") as f:
            f.write("")

    # check if .bash-preexec.sh exists
    if not os.path.isfile(os.path.expanduser("~/.bash-preexec.sh")):
        # Save .bash-preexec.sh to ~/.bash-preexec.sh
        subprocess.Popen(
            [
                "wget",
                "-O",
                "~/.bash-preexec.sh",
                "https://raw.githubusercontent.com/rcaloras/bash-preexec/master/bash-preexec.sh",
            ]
        )

    # check if .bashrc contains the source command
    with open(os.path.expanduser("~/.bashrc"), "r") as f:
        if "bash-preexec.sh" not in f.read():
            # if not, add the source command to .bashrc
            print("adding source command to .bashrc")
            with open(os.path.expanduser("~/.bashrc"), "a") as f:
                f.write("[[ -f ~/.bash-preexec.sh ]] && source ~/.bash-preexec.sh")


if __name__ == "__main__":
    install()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pre_pip']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.1.3,<9.0.0', 'rich>=12.6.0,<13.0.0']

entry_points = \
{'console_scripts': ['pre-pip = pre_pip.cli:cli']}

setup_kwargs = {
    'name': 'pre-pip',
    'version': '0.1.2',
    'description': 'Run some python before your pip commands.',
    'long_description': '<p align="center" style="height: 3em;">\n    <img src="pre-pip.svg" alt="pre-pip" align="center"></img>\n</p>\n<p align="center">\n    <em>Run some python code just before your pip commands.</em>\n</p>\n\n<p align="center">\n<a href="https://github.com/RatulMaharaj/pre-pip/actions/workflows/python-test-zsh.yml" target="_blank">\n    <img src="https://github.com/RatulMaharaj/pre-pip/actions/workflows/python-test-zsh.yml/badge.svg" alt="pytest zsh">\n</a>\n<a href="https://github.com/RatulMaharaj/pre-pip/actions/workflows/python-test-bash.yml" target="_blank">\n    <img src="https://github.com/RatulMaharaj/pre-pip/actions/workflows/python-test-bash.yml/badge.svg" alt="pytest bash">\n</a>\n<a href="https://pypi.org/project/pre-pip" target="_blank">\n    <img src="https://img.shields.io/pypi/v/pre-pip?color=%2334D058&label=pypi%20package" alt="Package version">\n</a>\n</p>\n\n<hr/>\n\n### Use cases\n\n- Before installing a package, check it against a list of known malicious packages.\n- Upgrade pip automatically before installing a package.\n- Inject pip proxy settings into the environment before installing a package.\n\nYou can use it to run any custom python code before a pip command is executed.\n\n### Supported shells\n\nThe following shells are currently supported:\n\n- `zsh`\n- `bash`\n\nI\'m currently working on adding support for `powershell` and will thereafter look at `fish`.\n\nContributions for any other shells are welcome.\n\n### Installation\n\n```sh\npip install pre-pip\n```\n\nThere is potential to make this `pipx` installable.\n\n### Usage\n\nInstall `pre-pip` into your `.*rc` file using:\n\n```sh\npre-pip install\n```\n\n### Register a custom demo hook\n\nCreate a new file called `hook.py` in your current directory with the following content:\n\n```python\n# hook.py\nfrom rich import print as rprint\n\n\ndef main(args):\n    rprint(\n        f"This [italic green]pre-pip[/italic green] hook received: [italic cyan]{args}[/italic cyan]",\n    )\n\n```\n\nRegister the hook using:\n\n```sh\npre-pip add hook.py\n```\n\nYou can view the list of registered hooks using:\n\n```sh\npre-pip list\n```\n\n### Uninstall\n\nUninstall `pre-pip` using:\n\n```sh\npre-pip uninstall\n```\n\nThis will remove the `pre-pip` hook from your `.*rc` file as well as all registered hooks.\n\nTo remove the pre-pip package, use:\n\n```sh\npip uninstall pre-pip\n```\n\n### License\n\n[MIT](LICENSE)\n',
    'author': 'Ratul Maharaj',
    'author_email': 'ratulmaharaj@looped.co.za',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.11,<4.0',
}


setup(**setup_kwargs)
